jacinle.utils.cache
===================

.. automodule:: jacinle.utils.cache

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      cached_property
      cached_result
      fs_cached_result
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: cached_property

.. autofunction:: cached_result

.. autofunction:: fs_cached_result


